@@ -3,6 +3,8 @@ use std::{
     time::{Duration, Instant},
 };
 
+//
+
 #[derive(Debug)]
 pub struct Reporter {
     count: u32,
@@ -19,11 +21,7 @@ pub struct Timer {
     begin: Instant,
 }
 
-impl Default for Reporter {
-    fn default() -> Self {
-        Self::new_with_interval(Duration::from_secs(3))
-    }
-}
+//
 
 impl Reporter {
     pub fn new() -> Self {
@@ -59,6 +57,16 @@ impl Reporter {
         should_report
     }
 
+    pub fn time<T, F>(&mut self, f: F) -> T
+    where
+        F: FnOnce() -> T,
+    {
+        let timer = self.begin();
+        let result = f();
+        self.end(timer);
+        result
+    }
+
     pub fn manual(&mut self, elapsed: Duration) -> bool {
         self.elapsed += elapsed;
         self.count += 1;
@@ -154,6 +162,12 @@ impl Reporter {
     }
 }
 
+impl Default for Reporter {
+    fn default() -> Self {
+        Self::new_with_interval(Duration::from_secs(3))
+    }
+}
+
 impl Deref for Timer {
     type Target = Instant;
 
