@@ -1,10 +1,9 @@
+use crate::event::{CustomEvent, Event};
 use gilrs::{Axis, Button, Event as GilrsEvent, EventType, GamepadId};
 use glam::Vec2;
 use std::collections::{hash_map::Entry, HashMap};
 use winit::event::{ElementState, KeyboardInput, ScanCode, VirtualKeyCode, WindowEvent};
 
-use crate::event::{CustomEvent, Event};
-
 //
 
 #[derive(Debug)]
@@ -14,9 +13,6 @@ pub struct InputState {
 
     players: Vec<Option<GamepadId>>,
     gamepads: HashMap<GamepadId, Gamepad>,
-
-    window_focused: bool,
-    should_close: bool,
 }
 
 #[derive(Debug, Default)]
@@ -183,9 +179,6 @@ impl Default for InputState {
 
             players: Default::default(),
             gamepads: Default::default(),
-
-            window_focused: Default::default(),
-            should_close: Default::default(),
         }
     }
 }
@@ -500,24 +493,12 @@ impl InputState {
                 ..
             } => self.update_key(input),
             // Event::DeviceEvent { event, .. } => log::debug!("device event: {event:?}"),
-            Event::WindowEvent {
-                event: WindowEvent::Focused(f),
-                ..
-            } => self.window_focused = *f,
-            Event::WindowEvent {
-                event: WindowEvent::CloseRequested,
-                ..
-            } => self.should_close = true,
             _ => (),
         }
     }
 
     //
 
-    pub fn window_focused(&self) -> bool {
-        self.window_focused
-    }
-
     pub fn gui_key_held(&self, key: VirtualKeyCode) -> bool {
         if let Some(value) = self.virtual_keymap.get(&key) {
             *value
@@ -612,10 +593,6 @@ impl InputState {
         }
     }
 
-    pub fn should_close(&self) -> bool {
-        self.should_close
-    }
-
     //
 
     fn gamepad_entry(&mut self, id: GamepadId) -> &'_ mut Gamepad {
